<?php
/**
 * Tradebiz functions and definitions
 * Tradebiz only works in WordPress 4.7 or later.
 *
 * @link https://developer.wordpress.org/themes/advanced-topics/child-themes/
 * @package Tradebiz
 */
final class Tradebiz_Theme{
	public function __construct(){
		# enqueue script
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'scripts' ) );

		# add scroll to top up button
		add_action( 'wp_footer', array( __CLASS__, 'add_button' ) );

		# action after theme
		add_action( 'after_setup_theme', array( __CLASS__, 'after_parent_theme' ) );

		# register nav bars
		add_action( 'after_setup_theme', array( __CLASS__ , 'nav_menu' ) );

		# register the header area
		add_action( 'widgets_init', array( __CLASS__ , 'header_area' ) );

		# header above section
		add_action(  'gutenbiz_before_header', array( __CLASS__, 'header_before' ), 0 );

		# header above section
		add_action(  'gutenbiz_after_header', array( __CLASS__, 'header_after' ) );

		# widget init
		add_action( 'widgets_init', array( __CLASS__, 'register_widget' ) );

		# adds class on body to customize blog layouts
		add_filter( 'body_class' , array( __CLASS__ , 'add_body_classes' ) );
	}

	/**
	 * adds class on body to customize blog layouts
	 *
	 * @static
	 * @access public
	 * @return object
	 * @since  1.0.0
	 *
	 * @package Tradebiz
	 */
	public static function add_body_classes( $classes ){
		if( gutenbiz_get( 'post-per-row' ) == '1' ){
			$classes[] = 'tradebiz-post-per-page-1';
		}

		if( gutenbiz_get( 'tradebiz-sticky-header' ) ){
			$classes[] = 'tradebiz-sticky-header';
		}

		return $classes;
	}

	/**
	 * Header before area
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function header_before(){
		if( is_active_sidebar( Gutenbiz_Helper::fn_prefix( 'header_before' ) ) ){
			dynamic_sidebar( Gutenbiz_Helper::fn_prefix( 'header_before' ) );
		}
	}

	/**
	 * Header after area
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function header_after(){
		if( is_active_sidebar( Gutenbiz_Helper::fn_prefix( 'header_after' ) ) ){
			dynamic_sidebar( Gutenbiz_Helper::fn_prefix( 'header_after' ) );
		}
	}
	/**
	 * Register Header Area in theme 
	 *
	 * @static
	 * @access public
	 * @return object
	 * @since  1.0.0
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function header_area(){
		register_sidebar( array(
	        'name' 			=> esc_html__( 'Before Header Widget Area', 'tradebiz' ),
	        'id' 			=> Gutenbiz_Helper::fn_prefix( 'header_before' ),
	        'description' 	=> esc_html__( 'Widgets in this area will be shown above the header', 'tradebiz' ),
	        'before_widget' => '<div id="%1$s" class="widget %2$s extra-widget-area container">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h2 class="widget-title">',
	        'after_title'   => '</h2>',
		));

		register_sidebar( array(
	        'name' 			=> esc_html__( 'After Header Widget Area', 'tradebiz' ),
	        'id' 			=> Gutenbiz_Helper::fn_prefix( 'header_after' ),
	        'description' 	=> esc_html__( 'Widgets in this area will be shown after the header', 'tradebiz' ),
	        'before_widget' => '<div id="%1$s" class="widget %2$s  extra-widget-area container">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h2 class="widget-title">',
	        'after_title'   => '</h2>',
		));
	}
	/**
	* Enqueue styles and scripts
	*
	* @static
	* @access public
	* @since  1.0.0
	*
	* @package Tradebiz
	*/
	public static function scripts(){
		$scripts = array(
			# enqueue parent stylesheet
			array(
				'handler'  => 'tradebiz',
				'style'    => get_template_directory_uri() . '/style.css',
				'version'  => wp_get_theme()->get('Version'),
				'absolute' => true,
				'minified' => false
			),
			array(
			    'handler' => 'tradebiz-script',
			    'script'  => 'assets/js/script.js',
			    'minified' => false
			),
			array(
			    'handler' => 'jquery-sticky',
			    'script'  => 'assets/js/jquery.sticky.js',
			    'minified' => false
			)
		);
		Gutenbiz_Helper::enqueue( $scripts );
	}

	/**
	 * After parent theme
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Tradebiz
	 */
	public static function after_parent_theme(){
		# remove action to add extra options
		remove_action( 'init', 'gutenbiz_advanced_options' );

		# include options file
		Gutenbiz_Helper::include( array(
			'advance-options'
		), 'includes/theme-options', '');

		# include dynamic css
		Gutenbiz_Helper::include( array(
			'common'
		), 'includes/dynamic-css', '');

		Gutenbiz_Helper::include( array(
			'class-excerpt'
		), 'classes', '' );

		# widget files
		Gutenbiz_Helper::include( array(
			'class-base-widget',
			'class-post-with-thumbnail',
			'class-profile-card'
		), 'classes/widget', '' );

		# filter to modify priority
		add_filter( Gutenbiz_Helper::with_prefix( 'customizer_get_defaults','_' ), array( __CLASS__ , 'change_defaults' ), 99 ,2 );

		#filter to change default on admin
		add_filter( Gutenbiz_Helper::fn_prefix( 'customizer_get_setting_arg' ), array( __CLASS__, 'change_default_admmin' ), 10, 2 );

		#search icon hide/show
		add_action( Gutenbiz_Helper::fn_prefix( 'before_header' ), array( __CLASS__, 'toggle_search_icon' ) );
	}

	/**
	 * Hide/show search icon
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Tradebiz
	 */
	public static function toggle_search_icon(){ 		
		if( !gutenbiz_get( 'enable-search' ) ){
			remove_action( Gutenbiz_Helper::with_prefix( 'after_primary_menu', '_' ), array( 'Gutenbiz_Theme', 'add_search_icon' ), 20 );
		}
	}

	/**
	 * Change default value
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Tradebiz
	 */	
	public static function change_defaults( $def, $instance ){
		$id = Gutenbiz_Helper::with_prefix( 'footer-copyright-text' );
		$per_row = Gutenbiz_Helper::with_prefix( 'post-per-row' );
		$sidebar = Gutenbiz_Helper::with_prefix( 'sidebar-position' );

		$def[ $id ] = esc_html__( 'Copyright &copy; 2021 | Tradebiz', 'tradebiz' );	
		$def[ $per_row ] = '1';
		$def[ $sidebar ] = 'right-sidebar';

		return $def;
	}

	/**
	 * Change default value on admin
	 *
	 * @static
	 * @access public
	 * @since  1.0.1
	 *
	 * @package Tradebiz
	 */	
	public static function change_default_admmin( $args, $field ){
		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'footer-copyright-text' ) ){
			$args[ 'default' ] = esc_html__( 'Copyright &copy; 2021 | Tradebiz', 'tradebiz' );
		}

		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'post-per-row' ) ){
			$args[ 'default' ] = '1';
		}

		if( $field[ 'id' ] == Gutenbiz_Helper::with_prefix( 'sidebar-position' ) ){
			$args[ 'default' ] = 'right-sidebar';
		}

		return $args;
	}

	/**
	 * Register navigation bar
	 *
	 * @static
	 * @access public
	 * @return object
	 * @since  1.0.0
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function nav_menu(){
		register_nav_menus(
			array(
				'footer-menu' => esc_html__( 'Footer Menu', 'tradebiz' )
			)
		);
	}

	/**
	 * Add scroll to top button on footer
	 *
	 * @static
	 * @access public
	 * @since  1.0.0
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function add_button(){
		$enable = gutenbiz_get( 'enable-scroll-to-top' );
		if( !$enable ){
			return;
		}?>
		<div class="tradebiz-scroll-to-top">
			<i class="fa fa-arrow-up"></i>
		</div>
	<?php }

	/**
	 * profile card template
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function the_profile_card( $author_id = false ){
		if( !$author_id ){
			return;
		}
		set_query_var( 'author_id', $author_id );
		get_template_part( 'templates/profile', 'card' );
	}

	/**
	 * returns users array
	 *
	 * @since 1.0.0
	 * @return array
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function get_users_list(){
		$users = get_users();
		$users_arr = array();
		foreach ( $users as $user ) {
			$users_arr[ $user->ID ] = ucfirst( $user->user_nicename );				
		}
		return $users_arr;
	}

	/**
	 * register widget
	 *
	 * Pass widget class in register_widget function.
	 * If more than one widget pass in array and run loop.
	 *
	 * @static
	 * @access public
	 * @since 1.0.0
	 * @return string
	 *
	 * @package Tradebiz WordPress Theme
	 */
	public static function register_widget() {
		$st_widgets = array(
			'Tradebiz_Post_With_Thumb_Widget',
			'Tradebiz_Profile_Card_Widget'
		);
		foreach ( $st_widgets as $widget ) {			
			register_widget( $widget );
		}
	}
}


new Tradebiz_Theme();